/**
 * @file   replicas.h
 * @brief  Replica functions (JSON serialization/deserialization).
 * @author Alejandro Álvarez Ayllón <aalvarez.cern.ch>
 */
#ifndef REPLICAS_H_
#define REPLICAS_H_

#include <apr_pools.h>
#include <dmlite/c/inode.h>
#include "../mod_dav/mod_dav.h"


struct dav_ns_replica_array {
  int             nreplicas;
  dmlite_replica *replicas;
  char           *action;
};

/**
 * Serialize a set of replicas to JSON.
 * @param pool      The pool where allocations should be performed.
 * @param nreplicas The number of replicas in the array.
 * @param replicas  An array of nreplicas replicas.
 * @return          The serialized version.
 */
char* dav_ns_serialize_replicas(apr_pool_t *pool,
                                int nreplicas,
                                dmlite_replica *replicas);
/**
 * Deserialize a set of replicas from JSON.
 * @param pool      The pool where allocations should be performed.
 * @param json_str  The JSON representation.
 * @param replicas  It has to point to a struct dav_ns_replica array, which will be initialized.
 * @return          NULL on success.
 */
dav_error* dav_ns_deserialize_replicas(apr_pool_t *pool,
                                       const char* json_str,
                                       struct dav_ns_replica_array* replicas);

#endif /* REPLICAS_H_ */
